import type { Categories, Characteristic, CharacteristicValue, HapStatusError, Logger, Nullable, PlatformAccessory, Service, WithUUID } from 'homebridge';
import type { TplinkSmarthomeConfig } from '../config';
import type TplinkSmarthomePlatform from '../platform';
import type { TplinkSmarthomeAccessoryContext } from '../platform';
import type { TplinkDevice } from '../utils';
export default abstract class HomekitDevice {
    readonly platform: TplinkSmarthomePlatform;
    readonly config: TplinkSmarthomeConfig;
    readonly tplinkDevice: TplinkDevice;
    readonly category: Categories;
    readonly log: Logger;
    homebridgeAccessory: PlatformAccessory<TplinkSmarthomeAccessoryContext>;
    private lsc;
    /**
     * Creates an instance of HomeKitDevice.
     */
    constructor(platform: TplinkSmarthomePlatform, config: TplinkSmarthomeConfig, homebridgeAccessory: PlatformAccessory<TplinkSmarthomeAccessoryContext> | undefined, tplinkDevice: TplinkDevice, category: Categories);
    get id(): string;
    get name(): string;
    get manufacturer(): string;
    get model(): string;
    get serialNumber(): string;
    get firmwareRevision(): string;
    get hardwareRevision(): string;
    abstract identify(): void;
    updateValue(service: Service, characteristic: Characteristic, value: Nullable<CharacteristicValue> | Error | HapStatusError): void;
    addService(serviceConstructor: typeof this.platform.Service.Outlet | typeof this.platform.Service.Lightbulb, // WithUUID<Service | typeof Service>,
    name: string): Service;
    protected logRejection(reason: unknown): void;
    protected removeServiceIfExists(service: WithUUID<typeof Service>): void;
    protected removeCharacteristicIfExists(service: Service, characteristic: WithUUID<new () => Characteristic>): void;
}
//# sourceMappingURL=index.d.ts.map